Re-exports
pub use slot_packer::compress_dir;pub use slot_packer::compress_dir_with_policy;pub use stream_packer::compress_stream;pub use stream_packer::compress_stream_with_policy;pub use stream_packer::compress_stream_with_sink;pub use stream_packer::compress_stream_with_sink_and_policy;pub use stream_packer::ArchiveEntry;pub use stream_packer::StreamCompressor;
Modules
- slot_
packer - Two-pass directory compression.
- stream_
packer - Streaming compressor (
compress_stream) on the canonical no-barrier Gatling engine:znippy_zoomies::gatling::ordered::run_ordered_sink.
Structs
- Skip
Policy - Re-exported so a caller can state what it already knows about its input
without also depending on
znippy-commondirectly. A batch-level compression policy: oneContentHintcovering everything in a run, plus the fallbacks for when the hint says nothing.
Enums
- Content
Hint - Re-exported so a caller can state what it already knows about its input
without also depending on
znippy-commondirectly. What a caller already knows about its content, if anything.